# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-08-12 09:06:24
@LastEditTime: 2020-11-26 14:25:02
@LastEditors: HuangJingCan
@Description: 淘宝top接口基础类
"""
from seven_cloudapp.handlers.seven_base import *

from seven_top import top

from seven_cloudapp.models.enum import *

from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.base.base_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *


class TopBaseHandler(SevenBaseHandler):
    """
    @description: 淘宝top接口基础类
    """
    def get_sku_info(self, num_iids, access_token):
        """
        @description: 获取sku信息
        @param num_iids：num_iids
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        if self.get_is_test() == True:
            sku_info = self.test_sku_info()
            return self.reponse_json_success(sku_info)

        resp = self.get_goods_list_for_goodsids(num_iids, access_token)

        # self.logger_info.info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token)
        if "items_seller_list_get_response" in resp.keys():
            if "items" in resp["items_seller_list_get_response"].keys():
                self.reponse_json_success(resp["items_seller_list_get_response"])
            else:
                prize = ActPrizeModel().get_entity("goods_id=%s and sku_detail<>'' and is_sku=1 ", params=int(num_iids))
                if prize:
                    sku_detail = json.loads(prize.sku_detail.replace('\'', '\"'))
                    self.reponse_json_success(sku_detail["items_seller_list_get_response"])
                else:
                    self.reponse_json_error("NoSku", "对不起，找不到该商品的sku")
        else:
            self.reponse_json_success(resp)

    def get_sku_name(self, num_iids, sku_id, access_token):
        """
        @description: 获取sku名称
        @param num_iids：num_iids
        @param sku_id：sku_id
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        if self.get_is_test() == True:
            return self.reponse_json_success(self.test_sku_info())

        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.ItemsSellerListGetRequest()

        req.fields = "num_iid,title,nick,input_str,property_alias,sku,props_name,pic_url"
        req.num_iids = num_iids

        resp = req.getResponse(access_token)

        # self.logger_info.info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token)
        if "items_seller_list_get_response" in resp.keys():
            if "items" in resp["items_seller_list_get_response"].keys():
                props_names = resp["items_seller_list_get_response"]["items"]["item"][0]["props_name"].split(';')
                for sku in resp["items_seller_list_get_response"]["items"]["item"][0]["skus"]["sku"]:
                    if sku["sku_id"] == sku_id:
                        props_name = [i for i in props_names if sku["properties"] in i]
                        if len(props_name) > 0:
                            # self.logger_info.info(props_name[0][(len(sku["properties"]) + 1):])
                            return props_name[0][(len(sku["properties"]) + 1):]
                        else:
                            # self.logger_info.info(sku["properties_name"].split(':')[1])
                            return sku["properties_name"].split(':')[1]
        return ""

    def test_sku_info(self):
        sku_info = {
            "items": {
                "item": [{
                    "input_str": "984055037,棉95% 聚氨酯弹性纤维(氨纶)5%,粉色-女款;颜色分类;黄色-男款",
                    "nick": "阪织屋旗舰店",
                    "num_iid": 615956945446,
                    "pic_url": "https://img.alicdn.com/bao/uploaded/i3/2089529736/O1CN01GdsGYs2Ln8i0Dxv3c_!!0-item_pic.jpg",
                    "property_alias": "",
                    "props_name":
                    "20000:223946830:品牌:阪织屋;20021:105255:面料主材质:棉;20509:28314:尺码:S;20509:28315:尺码:M;20509:28316:尺码:L;20509:28317:尺码:XL;20603:14031880:图案:卡通动漫;20608:31755:家居服风格:卡通;24477:47698:适用性别:情侣;31745:3500872:件数:2件;1627207:380784160:颜色分类:粉色-女款;1627207:15039988:颜色分类:黄色-男款;8560225:828918270:上市时间:2020年夏季;13021751:7837058106:款号:984055037;13328588:493262620:成分含量:81%(含)-95%(含);122216507:3216783:厚薄:薄款;122216515:4060838:适用场景:休闲家居;122216608:3267959:适用对象:青年;148380063:852538341:销售渠道类型:纯电商(只在线上销售);149422948:854658283:面料材质成分:棉95% 聚氨酯弹性纤维(氨纶)5%",
                    "skus": {
                        "sku": [{
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550372101",
                            "price": "329.00",
                            "properties": "1627207:380784160;20509:28314",
                            "properties_name": "1627207:380784160:颜色分类:粉色-女款;20509:28314:尺码:S",
                            "quantity": 28,
                            "sku_id": 4511701590232
                        }, {
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550372102",
                            "price": "329.00",
                            "properties": "1627207:380784160;20509:28315",
                            "properties_name": "1627207:380784160:颜色分类:粉色-女款;20509:28315:尺码:M",
                            "quantity": 73,
                            "sku_id": 4511701590233
                        }, {
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550372103",
                            "price": "329.00",
                            "properties": "1627207:380784160;20509:28316",
                            "properties_name": "1627207:380784160:颜色分类:粉色-女款;20509:28316:尺码:L",
                            "quantity": 71,
                            "sku_id": 4511701590234
                        }, {
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550384002",
                            "price": "369.00",
                            "properties": "1627207:15039988;20509:28315",
                            "properties_name": "1627207:15039988:颜色分类:黄色-男款;20509:28315:尺码:M",
                            "quantity": 0,
                            "sku_id": 4511701590235
                        }, {
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550384003",
                            "price": "369.00",
                            "properties": "1627207:15039988;20509:28316",
                            "properties_name": "1627207:15039988:颜色分类:黄色-男款;20509:28316:尺码:L",
                            "quantity": 53,
                            "sku_id": 4511701590236
                        }, {
                            "created": "2020-04-14 16:21:58",
                            "modified": "2020-06-21 00:07:43",
                            "outer_id": "9840550384004",
                            "price": "369.00",
                            "properties": "1627207:15039988;20509:28317",
                            "properties_name": "1627207:15039988:颜色分类:黄色-男款;20509:28317:尺码:XL",
                            "quantity": 23,
                            "sku_id": 4511701590237
                        }]
                    },
                    "title": "阪织屋睡衣女迪士尼情侣睡衣米老鼠棉质印花女士短袖短裤套头套装"
                }]
            }
        }
        return sku_info

    def get_taobao_order(self, open_id, access_token, start_created="", end_created=""):
        """
        @description: 获取淘宝订单
        @param open_id：open_id
        @param access_token：access_token
        @param start_created：开始时间
        @param end_created：结束时间
        @return 
        @last_editors: HuangJingCan
        """
        all_order = []
        has_next = True

        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.OpenTradesSoldGetRequest()

        req.fields = "tid,status,payment,price,created,orders,num,pay_time"
        req.type = "fixed"
        req.buyer_open_id = open_id
        req.page_size = 10
        req.page_no = 1
        req.use_has_next = "true"

        if start_created == "":
            start_timestamp = TimeHelper.get_now_timestamp() - 90 * 24 * 60 * 60
            start_created = TimeHelper.timestamp_to_format_time(start_timestamp)
        # start_created = "2020-06-01 00:00:00"
        req.start_created = start_created
        if end_created != "":
            req.end_created = end_created

        while has_next:
            resp = req.getResponse(access_token)

            # self.logger_info.info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token + "【获取订单】")
            if "open_trades_sold_get_response" in resp.keys():
                if "trades" in resp["open_trades_sold_get_response"].keys():
                    all_order = all_order + resp["open_trades_sold_get_response"]["trades"]["trade"]
                req.page_no += 1
                has_next = resp["open_trades_sold_get_response"]["has_next"]

        return all_order

    def test_order(self):
        test_order = '''
            [
                {
                "created": "2020-06-13 19:10:39",
                "price": "1.00",
                "num": 1,
                "payment": "1.00",
                "orders": {
                    "order": [
                    {
                        "refund_status": "Success",
                        "price": "1.00",
                        "num": 1,
                        "payment": "1.00",
                        "num_iid": 573998736785,
                        "pic_path": "https://img.alicdn.com/bao/uploaded/i2/2960093539/O1CN01onsXQ61c0uFhJBqiu_!!0-item_pic.jpg",
                        "sku_id": "4299761829877",
                        "oid": "820019170235115377",
                        "title": "歪瓜出品 测试链接请勿拍下 拍下不发货",
                        "status": "WAIT_SELLER_SEND_GOODS"
                    }
                    ]
                },
                "tid": "819703136929115378",
                "pay_time": "2020-06-13 19:10:44",
                "status": "WAIT_SELLER_SEND_GOODS"
                },
                {
                "created": "2020-05-09 17:09:49",
                "price": "1.00",
                "num": 1,
                "payment": "1.00",
                "orders": {
                    "order": [
                    {
                        "refund_status": "NO_REFUND",
                        "price": "1.00",
                        "num": 1,
                        "payment": "1.00",
                        "num_iid": 573998736786,
                        "pic_path": "https://img.alicdn.com/bao/uploaded/i2/2960093539/O1CN01onsXQ61c0uFhJBqiu_!!0-item_pic.jpg",
                        "sku_id": "4299761829877",
                        "oid": "820019170235115377",
                        "title": "歪瓜出品 测试链接请勿拍下 拍下不发货",
                        "status": "TRADE_CLOSED_BY_TAOBAO"
                    }
                    ]
                },
                "tid": "820019170235115377",
                "status": "TRADE_CLOSED_BY_TAOBAO"
                },
                {
                "created": "2020-05-09 17:09:09",
                "price": "1.00",
                "num": 1,
                "payment": "1.00",
                "orders": {
                    "order": [
                    {
                        "refund_status": "NO_REFUND",
                        "price": "1.00",
                        "num": 1,
                        "payment": "1.00",
                        "num_iid": 573998736786,
                        "pic_path": "https://img.alicdn.com/bao/uploaded/i2/2960093539/O1CN01onsXQ61c0uFhJBqiu_!!0-item_pic.jpg",
                        "sku_id": "4299761829877",
                        "oid": "820019362005115377",
                        "title": "歪瓜出品 测试链接请勿拍下 拍下不发货",
                        "status": "WAIT_BUYER_PAY"
                    }
                    ]
                },
                "tid": "820019362005115377",
                "status": "WAIT_BUYER_PAY"
                }
            ]
            '''
        return test_order

    def rewards_status(self):
        """
        @description: rewards_status
        @param 
        @return: 
        @last_editors: CaiYouBin
        """
        status = [
            #等待卖家发货
            "WAIT_SELLER_SEND_GOODS",
            #卖家部分发货
            "SELLER_CONSIGNED_PART",
            #等待买家确认收货
            "WAIT_BUYER_CONFIRM_GOODS",
            #买家已签收（货到付款专用）
            "TRADE_BUYER_SIGNED",
            #交易成功
            "TRADE_FINISHED"
        ]
        return status

    def refund_status(self):
        """
        @description: 给予奖励的子订单退款状态
        @param 
        @return: 
        @last_editors: CaiYouBin
        """
        status = [
            #没有退款
            "NO_REFUND",
            #退款关闭
            "CLOSED",
            #卖家拒绝退款
            "WAIT_SELLER_AGREE"
        ]
        return status

    def instantiate(self, user_nick, act_name, description, icon, name_ending):
        """
        @description: 实例化
        @param user_nick：用户昵称
        @param act_name：活动名称
        @param description：活动简介
        @param icon：活动图标
        @param name_ending：名称结尾
        @return app_info
        @last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id

        app_info_model = AppInfoModel()
        store_user_nick = user_nick.split(':')[0]
        app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
        if not app_info:
            if ":" in user_nick:
                return self.reponse_json_error("Error", "对不起，初次创建活动包含实例化，请试用主账号进行创建。")
            base_info_model = BaseInfoModel()
            base_info = base_info_model.get_entity()
            template_id = config.get_value("client_template_id")
            template_version = base_info.client_ver
            access_token = self.get_taobao_param().access_token
            app_info = self.instantiate_app(user_nick, open_id, description, icon, act_name, template_id, template_version, 1, access_token, name_ending)

            if isinstance(app_info, dict):
                if "error" in app_info.keys():
                    return self.reponse_json_error(app_info["error"], app_info["message"])

            self.create_operation_log(OperationType.add.value, app_info.__str__(), "instantiate", None, self.json_dumps(app_info))

        return app_info

    def instantiate_app(self, user_nick, open_id, description, icon, name, template_id, template_version, isfirst, access_token, name_ending):
        """
        @description: 实例化
        @param user_nick：用户昵称
        @param open_id：用户唯一标识
        @param description：活动简介
        @param icon：活动图标
        @param name：活动名称
        @param template_id：模板id
        @param template_version：模板版本
        @param isfirst：是否第一次
        @param access_token：access_token
        @param name_ending：name_ending
        @return app_info
        @last_editors: HuangJingCan
        """
        try:
            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
            req = top.api.MiniappTemplateInstantiateRequest()

            req.clients = "taobao,tmall"
            req.description = description
            shop_info = self.get_shop(access_token)

            if isfirst == 1:
                app_name = shop_info["shop_seller_get_response"]["shop"]["title"] + name_ending
            else:
                app_name = name
            # self.logger_info.info("【实例化名称】" + ":" + str(app_name))
            req.ext_json = "{ \"name\":\"" + app_name + "\"}"
            req.icon = icon
            req.name = app_name
            req.template_id = template_id
            req.template_version = template_version
            resp = req.getResponse(access_token)

            #录入数据库
            result_app = resp["miniapp_template_instantiate_response"]
            app_info_model = AppInfoModel()
            app_info = AppInfo()
            app_info.clients = req.clients
            app_info.app_desc = result_app["app_description"]
            app_info.app_icon = result_app["app_icon"]
            app_info.app_id = result_app["app_id"]
            app_info.app_name = result_app["app_name"]
            app_info.app_ver = result_app["app_version"]
            app_info.app_key = result_app["appkey"]
            app_info.preview_url = result_app["pre_view_url"]
            app_info.template_id = req.template_id
            app_info.template_ver = req.template_version

            if "shop_seller_get_response" in shop_info.keys():
                app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
                app_info.store_id = shop_info["shop_seller_get_response"]["shop"]["sid"]

            user_seller = self.get_user_seller(access_token)
            if "user_seller_get_response" in user_seller.keys():
                app_info.seller_id = user_seller["user_seller_get_response"]["user"]["user_id"]

            app_info.is_instance = 1
            app_info.store_user_nick = user_nick.split(':')[0]
            app_info.owner_open_id = open_id
            app_info.instance_date = self.get_now_datetime()
            app_info.modify_date = self.get_now_datetime()
            #上线
            online_app_info = self.online_app(app_info.app_id, template_id, template_version, app_info.app_ver, access_token)
            if "miniapp_template_onlineapp_response" in online_app_info.keys():
                app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]

            app_info.id = AppInfoModel().add_entity(app_info)

            return app_info
        except Exception as ex:
            self.logger_error.error(str(ex))
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=" in content:
                        if "名称已经存在" in content:
                            if isfirst == 1:
                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending)
                            else:
                                return {"error": "CreateError", "message": content[len("submsg="):]}
                        if "应用名称不合法" in content:
                            if isfirst == 1:
                                return self.instantiate_app(user_nick, open_id, description, icon, name, template_id, template_version, 0, access_token, name_ending)
                            else:
                                return {"error": "CreateError", "message": content[len("submsg="):]}
                        return {"error": "CreateError", "message": content[len("submsg="):]}

    def online_app(self, app_id, template_id, template_version, app_version, access_token):
        """
        @description: app上线
        @param app_id：app_id
        @param template_id：模板id
        @param template_version：模板版本
        @param app_version：app版本
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.MiniappTemplateOnlineappRequest()

        req.clients = "taobao,tmall"
        req.app_id = app_id
        req.template_id = template_id
        req.template_version = template_version
        req.app_version = app_version
        resp = req.getResponse(access_token)
        return resp

    def get_shop(self, access_token):
        """
        @description: 获取店铺信息
        @param access_token：access_token
        @return: 
        @last_editors: HuangJingCan
        """
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.ShopSellerGetRequest()

        req.fields = "sid,title,pic_path"
        resp = req.getResponse(access_token)
        return resp

    def get_user_seller(self, access_token):
        """
        @description: 获取关注店铺用户信息
        @param access_token：access_token
        @return: 
        @last_editors: HuangJingCan
        """
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.UserSellerGetRequest()

        req.fields = "user_id,nick,sex"
        resp = req.getResponse(access_token)
        return resp

    def get_dead_date(self, user_nick):
        """
        @description: 获取过期时间
        @param user_nick：用户昵称
        @return 
        @last_editors: HuangJingCan
        """
        if self.get_is_test() == True:
            return config.get_value("test_dead_date")
        try:
            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
            req = top.api.VasSubscribeGetRequest()

            req.article_code = config.get_value("article_code")
            req.nick = user_nick
            resp = req.getResponse(self.get_taobao_param().access_token)
            if "article_user_subscribe" not in resp["vas_subscribe_get_response"]["article_user_subscribes"].keys():
                return "expire"
            else:
                return resp["vas_subscribe_get_response"]["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
        except Exception as ex:
            self.logger_info.info("get_dead_date:" + str(ex))
            return config.get_value("test_dead_date")

    def get_token(self):
        """
        @description: 获取授权token
        @param 
        @return: 
        @last_editors: CaiYouBin
        """
        if self.get_is_test() == True:
            return ""

        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.ItemsOnsaleGetRequest()

        req.fields = "num_iid,title,nick,input_str,property_alias,sku,props_name,pic_url"
        req.page_no = 1
        req.page_size = 10

        try:
            resp = req.getResponse(self.get_taobao_param().access_token)

            return self.get_taobao_param().access_token
        except Exception as ex:
            return ""

    def get_goods_list(self, page_index, page_size, goods_name, order_tag, order_by, access_token):
        """
        @description: 导入商品列表（获取当前会话用户出售中的商品列表）
        @param page_index：页索引
        @param page_size：页大小
        @param goods_name：商品名称
        @param order_tag：order_tag
        @param order_by：排序类型
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        try:
            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
            req = top.api.ItemsOnsaleGetRequest()

            req.fields = "num_iid,title,nick,price,input_str,property_alias,sku,props_name,pic_url"
            req.page_no = page_index + 1
            req.page_size = page_size
            if goods_name != "":
                req.q = goods_name
            req.order_by = order_tag + ":" + order_by

            resp = req.getResponse(access_token)
            if resp:
                resp["pageSize"] = page_size
                resp["pageIndex"] = page_index

            # self.logger_info.info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token)
            self.reponse_json_success(resp)
        except Exception as ex:
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        return self.reponse_json_error("NoPower", content[len("submsg="):])
                    if "submsg=" in content:
                        return self.reponse_json_error("Error", content[len("submsg="):])

    def test_goods_list(self):
        """
        @description: 测试商品列表
        @param {type} 
        @return {type} 
        @last_editors: HuangJingCan
        """
        goods_list_json = {
            'items_onsale_get_response': {
                'items': {
                    'item': [{
                        'nick': 'loveyouhk',
                        'num_iid': 619094193197,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i2/305104024/T2YY4jXfXcXXXXXXXX_!!305104024.jpg',
                        'title': '测试5'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 619618211537,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i4/305104024/O1CN01H7Leza1fb2MFvH3V9_!!305104024.jpg',
                        'title': '测试4'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 616454842353,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN0123kpnE1fb2MHUgGsr_!!305104024.jpg',
                        'title': '测试宝贝3'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 620482187181,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i2/305104024/T2YY4jXfXcXXXXXXXX_!!305104024.jpg',
                        'title': '测试宝贝9'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 620482163358,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN01XWvOUt1fb2N6fanuW_!!305104024.png',
                        'title': '测试宝贝10测试宝贝10测试宝贝10测试宝贝10测试宝贝10测试宝贝10'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 620215826949,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN01XWvOUt1fb2N6fanuW_!!305104024.png',
                        'title': '测试宝贝8'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 620480991439,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN01XWvOUt1fb2N6fanuW_!!305104024.png',
                        'title': '测试宝贝7'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 616631743105,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN0123kpnE1fb2MHUgGsr_!!305104024.jpg',
                        'title': '测试宝贝2'
                    }, {
                        'nick': 'loveyouhk',
                        'num_iid': 613878861009,
                        'pic_url': 'https://img.alicdn.com/bao/uploaded/i1/305104024/O1CN0123kpnE1fb2MHUgGsr_!!305104024.jpg',
                        'title': '测试商品1'
                    }]
                },
                'total_results': 9,
                'request_id': '3gx6au6cs9y0'
            },
            'pageSize': 10,
            'pageIndex': 0
        }
        return goods_list_json

    def get_goods_list_client(self, page_index, page_size, access_token):
        """
        @description: 导入商品列表（客户端）
        @param page_index：页索引
        @param page_size：页大小
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        try:
            resp = {}
            if self.get_is_test() == True:
                resp = self.test_goods_list()
            else:
                top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
                req = top.api.ItemsOnsaleGetRequest()

                req.fields = "num_iid,title,nick,pic_url,price"
                req.page_no = page_index + 1
                req.page_size = page_size

                resp = req.getResponse(access_token)
                # self.logger_info.info(str(resp))
            goods_list = []
            if "items_onsale_get_response" in resp.keys():
                if "items" in resp["items_onsale_get_response"]:
                    if "item" in resp["items_onsale_get_response"]["items"]:
                        if len(resp["items_onsale_get_response"]["items"]["item"]) > 10:
                            goods_index_list = range(len(resp["items_onsale_get_response"]["items"]["item"]))
                            indexs = random.sample(goods_index_list, 10)
                            for i in range(0, 10):
                                goods_list.append(resp["items_onsale_get_response"]["items"]["item"][indexs[i]])
                        else:
                            goods_list = resp["items_onsale_get_response"]["items"]["item"]

                        random.randint(0, len(resp["items_onsale_get_response"]["items"]["item"]))
            if resp:
                resp["pageSize"] = page_size
                resp["pageIndex"] = page_index

            self.reponse_json_success(goods_list)
        except Exception as ex:
            # self.logger_info.info(str(ex) + "【access_token】：" + self.get_taobao_param().access_token)
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        return self.reponse_json_error("NoPower", content[len("submsg="):])
                    if "submsg=" in content:
                        return self.reponse_json_error("Error", content[len("submsg="):])

    def get_goods_info(self, num_iid, access_token):
        """
        @description: 导入商品列表
        @param num_iids：num_iids
        @param access_token：access_token
        @return 
        @last_editors: HuangJingCan
        """
        try:
            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
            req = top.api.ItemSellerGetRequest()

            req.fields = "num_iid,title,nick,pic_url,price,item_img.url,outer_id,sku,approve_status"
            req.num_iid = num_iid

            resp = req.getResponse(access_token)
            # self.logger_info.info(str(resp))
            self.reponse_json_success(resp)
        except Exception as ex:
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        return self.reponse_json_error("NoPower", content[len("submsg="):])
                    if "submsg=该商品已被删除" in content:
                        return self.reponse_json_error("GoodsDel", content[len("submsg="):])
                    if "submsg=" in content:
                        return self.reponse_json_error("Error", content[len("submsg="):])

    def test_goods_info(self):
        """
        @description: 测试商品
        @param {type} 
        @return {type} 
        @last_editors: HuangJingCan
        """
        goods_json = {
            'item_seller_get_response': {
                'item': {
                    'props_name': '20000:3275069:品牌:盈讯;1753146:3485013:型号:F908;30606:112030:上市时间:2008年',
                    'property_alias': '20000:3275069:盈讯;1753146:3485013:F908;30606:112030:2008年',
                    'approve_status': 'onsale',
                    'item_imgs': {
                        'item_img': [{
                            'url': 'https://img.alicdn.com/bao/uploaded/i2/2960093539/O1CN01IHRzmN1c0uHV10kHG_!!2960093539-0-lubanu-s.jpg'
                        }, {
                            'url': 'https://img.alicdn.com/bao/uploaded/i4/2960093539/O1CN01vHPntd1c0uHU5Yk9u_!!2960093539-0-lubanu-s.jpg'
                        }, {
                            'url': 'https://img.alicdn.com/bao/uploaded/i1/2960093539/O1CN01VSRPZk1c0uHaEcUUs_!!2960093539-0-lubanu-s.jpg'
                        }, {
                            'url': 'https://img.alicdn.com/bao/uploaded/i3/2960093539/O1CN018piHzr1c0uHTeKlAo_!!2960093539-0-lubanu-s.jpg'
                        }, {
                            'url': 'https://img.alicdn.com/bao/uploaded/i3/2960093539/O1CN01z2Qfot1c0uHZBEds4_!!2960093539-0-lubanu-s.jpg'
                        }]
                    },
                    'nick': '歪瓜出品旗舰店',
                    'num_iid': 620003498461,
                    'pic_url': 'https://img.alicdn.com/bao/uploaded/i2/2960093539/O1CN01IHRzmN1c0uHV10kHG_!!2960093539-0-lubanu-s.jpg',
                    'price': '60.00',
                    'skus': {
                        'sku': [{
                            'created': '2020-06-05 14:53:50',
                            'modified': '2020-06-10 15:29:53',
                            'outer_id': 'XNYY-ND001',
                            'price': '60.00',
                            'properties': '134942334:28316;1627207:3232483',
                            'properties_name': '134942334:28316:大小:L;1627207:3232483:颜色分类:军绿色',
                            'quantity': 1000,
                            'sku_id': 4552779199857
                        }, {
                            'created': '2020-06-05 14:53:50',
                            'modified': '2020-06-10 15:29:53',
                            'outer_id': 'XNYY-ND002',
                            'price': '120.00',
                            'properties': '134942334:28316;1627207:90554',
                            'properties_name': '134942334:28316:大小:L;1627207:90554:颜色分类:桔色',
                            'quantity': 1000,
                            'sku_id': 4552779199858
                        }, {
                            'created': '2020-06-05 14:53:50',
                            'modified': '2020-06-10 15:29:53',
                            'outer_id': 'XNYY-ND003',
                            'price': '200.00',
                            'properties': '134942334:28316;1627207:60092',
                            'properties_name': '134942334:28316:大小:L;1627207:60092:颜色分类:浅黄色',
                            'quantity': 1000,
                            'sku_id': 4552779199859
                        }, {
                            'created': '2020-06-05 14:53:50',
                            'modified': '2020-06-10 15:29:53',
                            'outer_id': 'XNYY-ND004',
                            'price': '600.00',
                            'properties': '134942334:28316;1627207:3232479',
                            'properties_name': '134942334:28316:大小:L;1627207:3232479:颜色分类:深紫色',
                            'quantity': 1000,
                            'sku_id': 4552779199860
                        }, {
                            'created': '2020-06-05 14:53:50',
                            'modified': '2020-06-10 15:29:53',
                            'outer_id': 'XNYY-ND005',
                            'price': '1200.00',
                            'properties': '134942334:28316;1627207:3232480',
                            'properties_name': '134942334:28316:大小:L;1627207:3232480:颜色分类:粉红色',
                            'quantity': 1000,
                            'sku_id': 4552779199861
                        }]
                    },
                    'title': '歪瓜出品 在线抽盒机一番赏扭蛋盲盒 扭蛋币购买不支持退货退款'
                },
                'request_id': '3pwgypud7ycy'
            }
        }
        return goods_json

    def app_update(self):
        """
        @description: app更新
        @param 
        @return 
        @last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        client_template_id = config.get_value("client_template_id")
        test_client_ver = config.get_value("test_client_ver")
        access_token = self.get_taobao_param().access_token

        base_info = BaseInfoModel().get_entity()
        client_ver = base_info.client_ver

        app_info_model = AppInfoModel()
        app_info = app_info_model.get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，找不到该APP")
        old_app_info = app_info

        #指定账号升级
        if test_client_ver:
            user_nick = self.get_taobao_param().user_nick
            if user_nick:
                if user_nick == config.get_value("test_user_nick"):
                    client_ver = test_client_ver

        #更新
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.MiniappTemplateUpdateappRequest()

        req.clients = "taobao,tmall"
        req.app_id = app_id
        req.template_id = client_template_id
        req.template_version = client_ver
        try:
            resp = req.getResponse(access_token)

            if resp and ("miniapp_template_updateapp_response" in resp.keys()):
                app_version = resp["miniapp_template_updateapp_response"]["app_version"]
                online_app_info = self.online_app(app_id, client_template_id, client_ver, app_version, access_token)
                if "miniapp_template_onlineapp_response" in online_app_info.keys():
                    app_info.app_ver = resp["miniapp_template_updateapp_response"]["app_version"]
                    app_info.template_ver = client_ver
                    app_info.modify_date = self.get_now_datetime()
                    app_info_model.update_entity(app_info)

            # self.logger_info.info(str(resp) + "【更新】")

            self.create_operation_log(OperationType.update.value, app_info.__str__(), "AppUpdateHandler", self.json_dumps(old_app_info), self.json_dumps(app_info))

            self.reponse_json_success()
        except Exception as ex:
            if "submsg" in str(ex):
                self.logger_error.error(str(ex) + "【更新】")
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        return self.reponse_json_error("NoPower", content[len("submsg="):])
                    if "submsg=" in content:
                        return self.reponse_json_error("Error", content[len("submsg="):])


    def change_throw_goods_list_status(self, throw_goods_ids, url, status):
        """
        @description: change_throw_goods_list_status
        @param throw_goods_ids：throw_goods_ids
        @param url：链接地址
        @param status：状态
        @return 
        @last_editors: HuangJingCan
        """
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.MiniappDistributionItemsBindRequest()

        req.target_entity_list = throw_goods_ids
        req.url = url
        req.add_bind = status
        resp = req.getResponse(self.get_taobao_param().access_token)
        return resp

    def get_goods_list_for_goodsids(self, num_iids, access_token):
        """
        @description: 批量获取商品详细信息
        @param num_iids：商品id列表
        @param access_token：access_token
        @return list
        @last_editors: HuangJingCan
        """
        try:
            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
            req = top.api.ItemsSellerListGetRequest()

            req.fields = "num_iid,title,nick,input_str,property_alias,sku,props_name,pic_url"
            req.num_iids = num_iids
            resp = req.getResponse(access_token)
            return resp
        except Exception as ex:
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        return {"error_code": "NoPower", "error_message": content[len("submsg="):]}
                    if "submsg=" in content:
                        return {"error_code": "Error", "error_message": content[len("submsg="):]}

    def get_taobao_order_info(self, order_no, access_token):
        """
        @description: 获取单笔订单
        @param order_no：订单编号
        @param access_token：access_token
        @return: 
        @last_editors: CaiYouBin
        """
        top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
        req = top.api.OpenTradeGetRequest()

        req.fields = "tid,status,payment,price,created,orders,num,pay_time,buyer_open_uid"
        req.tid = order_no

        resp = req.getResponse(access_token)

        if "open_trade_get_response" in resp.keys():
            if "trade" in resp["open_trade_get_response"]:
                return resp["open_trade_get_response"]["trade"]
            return None

    def test_order_info(self):
        test_order = {
            "open_trade_get_response": {
                "trade": {
                    "tid": "819703136929115378",
                    "num": 1,
                    "num_iid": 3424234,
                    "status": "TRADE_NO_CREATE_PAY",
                    "type": "fixed(一口价)",
                    "price": "5.00",
                    "total_fee": "5.00",
                    "created": "2000-01-01 00:00:00",
                    "orders": {
                        "order": [{
                            "outer_iid": "152e442aefe88dd41cb0879232c0dcb0",
                            "oid": "819703136929115378",
                            "status": "TRADE_NO_CREATE_PAY",
                            "price": "5.00",
                            "num_iid": 2342344,
                            "sku_id": "5937146",
                            "num": 1,
                            "outer_sku_id": "81893848",
                            "total_fee": "5.00",
                            "pic_path": "http:\/\/img08.taobao.net\/bao\/uploaded\/i8\/T1jVXXXePbXXaoPB6a_091917.jpg",
                            "title": "测试机器",
                            "payment": "5.00",
                            "customization": "{ \"itemId\": 123, \"skuId\": 123, \"text\": [ { \"id\": 44, \"content\": \"home\" } ], \"pic\": [ { \"id\": 44, \"url\": \"sn\" } ] ,\"dingzhi\":\";pluginId:182;dingzhiId:157886;\"}"
                        }]
                    },
                    "payment": "5.00",
                    "buyer_open_uid": "AAFisaLrAKYmeFNoo7oWNA5S",
                    "pay_time": "2000-01-01 00:00:00",
                    "seller_memo": "好的",
                    "buyer_memo": "上衣要大一号"
                }
            }
        }

        if "open_trade_get_response" in test_order.keys():
            if "trade" in test_order["open_trade_get_response"]:
                return test_order["open_trade_get_response"]["trade"]
            return None


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-19 11:59:38
@LastEditTime: 2020-11-20 16:17:52
@LastEditors: HuangJingCan
@Description: 
"""
__all__ = ["act", "address", "app", "goods", "lottery", "machine", "prize", "theme", "user"]



# -*- coding: utf-8 -*-
"""
@Author: CaiYouBin
@Date: 2020-05-12 20:04:54
@LastEditTime: 2020-11-24 17:16:36
@LastEditors: HuangJingCan
@Description: 基础接口
"""
import random
from seven_cloudapp.handlers.seven_base import *
from seven_framework.qr_code import *

from seven_cloudapp.models.enum import *
from seven_cloudapp.models.seven_model import PageInfo

from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_type_model import *
from seven_cloudapp.models.db_models.marketing.marketing_program_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.base.base_info_model import *


class MarketingProgramHandler(SevenBaseHandler):
    """
    @description: 营销方案
    """
    def get_async(self):
        """
        @description: 营销方案获取
        @param {type} 
        @return: 列表
        @last_editors: HuangJingCan
        """
        marketing_program_list = MarketingProgramModel().get_dict_list()

        self.reponse_json_success(marketing_program_list)


class ActTypeHandler(SevenBaseHandler):
    """
    @description: 活动类型相关
    """
    def post_async(self):
        """
        @description: 活动类型入库
        @param type_id：类型id
        @param type_name：类型名称
        @param act_title：活动标题
        @param act_img：活动图
        @param experience_img：体验码二维码图
        @param play_process：玩法流程
        @param applicable_behavior：适用行为
        @param market_function：营销功能
        @return: 
        @last_editors: HuangJingCan
        """
        type_id = int(self.get_param("type_id", "0"))
        type_name = self.get_param("type_name")
        act_title = self.get_param("act_title")
        act_img = self.get_param("act_img")
        experience_img = self.get_param("experience_img")
        play_process = self.get_param("play_process")
        applicable_behavior = self.get_param("applicable_behavior")
        market_function = self.get_param("market_function")

        # 数据入库
        act_type_model = ActTypeModel()
        act_type = None
        if type_id > 0:
            act_type = act_type_model.get_entity_by_id(type_id)

        is_add = False
        if not act_type:
            is_add = True
            act_type = ActType()

        act_type.type_name = type_name
        act_type.act_title = act_title
        act_type.act_img = act_img
        act_type.experience_img = experience_img
        act_type.play_process = play_process
        act_type.applicable_behavior = applicable_behavior
        act_type.market_function = market_function
        act_type.modify_date = self.get_now_datetime()

        if is_add:
            act_type.create_date = act_type.modify_date
            act_type_model.add_entity(act_type)
        else:
            act_type_model.update_entity(act_type)

        self.reponse_json_success()

    def get_async(self):
        """
        @description: 活动类型获取（弃用）
        @param marketing_id：营销方案id
        @return: 列表
        @last_editors: HuangJingCan
        """
        marketing_id = int(self.get_param("marketing_id", 0))
        condition = ""
        if marketing_id > 0:
            condition = "marketing_id LIKE '%," + str(marketing_id) + ",%'"

        act_type_model = ActTypeModel()
        act_type_list = act_type_model.get_list(condition)

        new_list = []

        for info in act_type_list:
            if info.play_process:
                info.play_process = ast.literal_eval(info.play_process)
            if info.applicable_behavior:
                info.applicable_behavior = ast.literal_eval(info.applicable_behavior)
            if info.market_function:
                info.market_function = ast.literal_eval(info.market_function)
            if info.skill_case:
                info.skill_case = ast.literal_eval(info.skill_case)
            new_list.append(info.__dict__)

        self.reponse_json_success(new_list)


class ActTypeListHandler(SevenBaseHandler):
    """
    @description: 活动类型列表
    """
    def get_async(self):
        """
        @description: 活动类型获取
        @param marketing_id：营销方案id
        @return: 列表
        @last_editors: HuangJingCan
        """
        marketing_id = int(self.get_param("marketing_id", 0))
        condition = ""
        if marketing_id > 0:
            condition = "marketing_id LIKE '%," + str(marketing_id) + ",%'"

        act_type_model = ActTypeModel()
        act_type_list = act_type_model.get_list(condition)

        new_list = []

        for info in act_type_list:
            if info.play_process:
                info.play_process = ast.literal_eval(info.play_process)
            if info.applicable_behavior:
                info.applicable_behavior = ast.literal_eval(info.applicable_behavior)
            if info.market_function:
                info.market_function = ast.literal_eval(info.market_function)
            if info.skill_case:
                info.skill_case = ast.literal_eval(info.skill_case)
            new_list.append(info.__dict__)

        self.reponse_json_success(new_list)


class ActCreateHandler(SevenBaseHandler):
    """
    @description: 创建活动（业务各自实现）
    """
    @filter_check_params("act_type")
    def get_async(self):
        """
        @description: 创建活动（业务各自实现）
        @param act_type：活动类型
        @return: 
        @last_editors: HuangJingCan
        """
        pass


class ActHandler(SevenBaseHandler):
    """
    @description: 修改活动
    """
    @filter_check_params("act_id,act_name")
    def post_async(self):
        """
        @description: 修改活动
        @param app_id：app_id
        @param owner_open_id：owner_open_id
        @param act_name：活动名称
        @param act_type：活动类型
        @param theme_id：主题ID
        @param store_url：店铺地址
        @param close_word：关闭小程序文案
        @param share_desc：分享内容
        @param rule_desc：规则内容
        @param start_date：开始时间
        @param end_date：结束时间
        @param refund_count：退款次数
        @param is_black：是否开启黑名单
        @param sort_index：排序号
        @param is_release：是否发布（1是0否）
        @param is_throw：是否开启投放（1是0否）
        @param join_ways：活动参与条件（0所有1关注店铺2加入会员）
        @param is_fictitious：是否开启虚拟中奖
        @param currency_type 抽奖货币类型（0无1次数2积分3价格档位4抽奖码）
        @param lottery_value 单次抽奖消耗次数（积分）
        @return act_id
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_param("app_id")
        owner_open_id = self.get_param("owner_open_id")
        act_name = self.get_param("act_name")
        theme_id = int(self.get_param("theme_id", 1))
        store_url = self.get_param("store_url")
        close_word = self.get_param("close_word", "抱歉，程序维护中")
        share_desc = self.get_param("share_desc")
        rule_desc = self.get_param("rule_desc")
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")
        refund_count = int(self.get_param("refund_count", 0))
        is_black = int(self.get_param("is_black", 0))
        sort_index = int(self.get_param("sort_index", 1))
        is_release = int(self.get_param("is_release", 0))
        # is_throw = int(self.get_param("is_throw", 0))
        join_ways = int(self.get_param("join_ways", 0))
        is_fictitious = int(self.get_param("is_fictitious", 0))
        lottery_value = int(self.get_param("lottery_value", 0))

        act_info_model = ActInfoModel()
        if act_id > 0:
            act_info = act_info_model.get_entity_by_id(act_id)

            old_act_info = copy.deepcopy(act_info)

            act_info.act_name = act_name
            act_info.theme_id = theme_id
            act_info.store_url = store_url
            act_info.close_word = close_word
            act_info.share_desc = share_desc if share_desc != "" else []
            act_info.rule_desc = rule_desc if rule_desc != "" else []
            act_info.start_date = start_date
            act_info.end_date = end_date
            act_info.refund_count = refund_count
            act_info.is_black = is_black
            act_info.sort_index = sort_index
            act_info.is_release = is_release
            # act_info.is_throw = is_throw
            act_info.join_ways = join_ways
            act_info.is_fictitious = is_fictitious
            act_info.lottery_value = lottery_value
            act_info.modify_date = self.get_now_datetime()

            act_info_model.update_entity(act_info)

            self.create_operation_log(OperationType.update.value, act_info.__str__(), "ActHandler", self.json_dumps(old_act_info), self.json_dumps(act_info))

        self.reponse_json_success()


class ActListHandler(SevenBaseHandler):
    """
    @description: 活动列表
    """
    def get_async(self):
        """
        @description: 获取活动列表
        @param act_name：活动名称
        @param page_index：页索引
        @param page_size：页大小
        @return: PageInfo
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        is_del = int(self.get_param("is_del", 0))
        act_name = self.get_param("act_name")
        app_id = self.get_param("app_id")

        if app_id:
            order_by = "id ASC"
            condition = "app_id=%s"
            if is_del == 0:
                condition += "AND is_del=0"
            else:
                condition += "AND is_del=1"

            page_list, total = ActInfoModel().get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)

            for page in page_list:
                page["share_desc"] = json.loads(page["share_desc"]) if page["share_desc"] else []
                page["rule_desc"] = json.loads(page["rule_desc"]) if page["rule_desc"] else []
                page["menu_configed"] = json.loads(page["menu_configed"]) if page["menu_configed"] else []
                page["share_desc"] = f"https://m.duanqu.com/?_ariver_appid={app_id}&query=" + CodingHelper.url_encode(f"actid={page['id']}")
                page["live_url"] = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"

            page_info = PageInfo(page_index, page_size, total, page_list)

            self.reponse_json_success(page_info)
        else:
            self.reponse_json_success({"data": []})


class ActInfoHandler(SevenBaseHandler):
    """
    @description: 活动信息获取
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 活动信息获取
        @param act_id：活动id
        @return: 活动信息
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))

        act_info = ActInfoModel().get_entity_by_id(act_id)

        if act_info:
            act_info.share_desc = json.loads(act_info.share_desc) if act_info.share_desc != "" else []
            act_info.rule_desc = json.loads(act_info.rule_desc) if act_info.rule_desc != "" else []
            act_info.menu_configed = json.loads(act_info.menu_configed) if act_info.menu_configed != "" else []
            act_info.online_url = f"https://m.duanqu.com/?_ariver_appid={act_info.app_id}&query=" + CodingHelper.url_encode(f"actid={act_info.id}")
            act_info.live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={act_info.app_id}"

            self.reponse_json_success(act_info)
        else:
            self.reponse_json_success()


class ActDelHandler(SevenBaseHandler):
    """
    @description: 删除或者还原活动
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 删除或者还原活动
        @param act_id：活动id
        @param is_del：0-还原，1-删除
        @return: 
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", "0"))
        is_del = int(self.get_param("is_del", "1"))
        modify_date = self.get_now_datetime()

        if act_id <= 0:
            return self.reponse_json_error_params()
        if is_del == 1:
            ActInfoModel().update_table("is_del=%s,modify_date=%s,is_release=0", "id=%s", [is_del, modify_date, act_id])
        else:
            ActInfoModel().update_table("is_del=%s,modify_date=%s,is_release=1", "id=%s", [is_del, modify_date, act_id])

        self.reponse_json_success()


class ActQrCodeHandler(SevenBaseHandler):
    """
    @description: 活动二维码获取
    """
    @filter_check_params("url")
    def get_async(self):
        """
        @description: 活动二维码获取
        @param act_id：活动id
        @return: 活动二维码图片
        @last_editors: HuangJingCan
        """
        url = self.get_param("url")

        img, img_bytes = QRCodeHelper.create_qr_code(url, fill_color="black")
        img_base64 = base64.b64encode(img_bytes).decode()

        self.reponse_json_success(f"data:image/jpeg;base64,{img_base64}")


class ActReviewHandler(SevenBaseHandler):
    """
    @description: 还原活动
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 还原活动
        @param act_id：活动id
        @return 
        @last_editors: HuangJingCan
        """
        act_id = self.get_param("act_id")
        modify_date = self.get_now_datetime()
        user_nick = self.get_taobao_param().user_nick
        store_user_nick = user_nick.split(':')[0]
        dict_app_id = AppInfoModel().get_dict("store_user_nick=%s", field="app_id", params=store_user_nick)
        if not dict_app_id:
            return self.reponse_json_error("NoAppId", "对不起，app_id不存在")

        act_info_model = ActInfoModel()
        act_info_total = act_info_model.get_total("app_id=%s and is_del=0", params=dict_app_id["app_id"])
        if act_info_total > 9:
            return self.reponse_json_error("OverAct", "对不起，活动不可超过10个")
        act_info_model.update_table("is_del=0,modify_date=%s,is_release=1", "id=%s", [modify_date, act_id])

        self.reponse_json_success()


class NextProgressHandler(SevenBaseHandler):
    """
    @description: 下一步
    """
    def get_async(self):
        """
        @description: 下一步
        @param act_id：活动id
        @param finish_key：finish_key
        @return 
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id"))
        finish_key = self.get_param("finish_key")
        base_info = BaseInfoModel().get_entity()
        if not base_info:
            return self.reponse_json_error("Error", "对不起，请与管理员联系")

        act_info_model = ActInfoModel()
        act_info = act_info_model.get_entity("id=%s", params=act_id)

        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到当前活动")

        menu_config = json.loads(base_info.menu_config)
        menu = [menu for menu in menu_config if menu["key"] == finish_key]
        if len(menu) == 0:
            return self.reponse_json_error("Error", "对不起，无此菜单")

        if act_info.menu_configed != "" and finish_key in act_info.menu_configed:
            return self.reponse_json_success()

        if act_info.menu_configed == "":
            act_info.menu_configed = "[]"

        menu_configed = json.loads(act_info.menu_configed)
        menu_configed.append(finish_key)

        result_menu_configed = []
        for item in menu_configed:
            is_exist = [item2 for item2 in menu_config if item2["key"] == item]
            if len(is_exist) > 0:
                result_menu_configed.append(item)
        if len(result_menu_configed) == len(menu_config) and act_info.finish_progress == 0:
            act_info.finish_progress = 1

        act_info.menu_configed = json.dumps(result_menu_configed)

        act_info_model.update_entity(act_info)

        self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-24 17:26:33
@LastEditTime: 2020-11-23 16:37:25
@LastEditors: HuangJingCan
@Description: 基础信息相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.base.base_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *


class LeftNavigationHandler(SevenBaseHandler):
    """
    @description: 左侧导航栏
    """
    def get_async(self):
        """
        @description: 左侧导航栏
        @param {*}
        @return 字典
        @last_editors: HuangJingCan
        """
        base_info = BaseInfoModel().get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")
        store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
        if not store_user_nick:
            return self.reponse_json_error("Error", "对不起，请先授权登录")
        open_id = self.get_taobao_param().open_id
        if not open_id:
            return self.reponse_json_error("Error", "对不起，请先登录")
        open_id = self.get_taobao_param().open_id
        app_info = AppInfoModel().get_entity("store_user_nick=%s", params=store_user_nick)
        if not app_info:
            return self.reponse_json_error("AppInfoError", "App信息出错")

        # 左上角信息
        info = {}
        info["company"] = "天志互联"
        info["miniappName"] = config.get_value("project_name")
        info["logo"] = config.get_value("project_logo")

        # 左边底部菜单
        helper_info = {}
        helper_info["customer_service"] = "http://amos.alicdn.com/getcid.aw?v=2&uid=%E5%A4%A9%E5%BF%97%E4%BA%92%E8%81%94&site=cntaobao&s=1&groupid=0&charset=utf-8"
        helper_info["video_url"] = base_info.video_url
        helper_info["study_url"] = base_info.study_url
        helper_info["is_remind_phone"] = base_info.is_remind_phone
        helper_info["phone"] = app_info.app_telephone

        # 过期时间
        renew_info = {}
        renew_info["dead_date"] = app_info.expiration_date
        # if app_info.expiration_date == "1900-01-01 00:00:00":
        #     app_info.expiration_date = TimeHelper.add_days_by_format_time(self.get_now_datetime(), 10)
        renew_info["surplus_day"] = TimeHelper.difference_days(app_info.expiration_date, self.get_now_datetime())
        # renew_info["renew_prices"] = base_info.product_price

        data = {}
        data["app_info"] = info
        data["helper_info"] = helper_info
        data["renew_info"] = renew_info
        if base_info.product_price:
            data["renew_prices"] = ast.literal_eval(base_info.product_price)

        self.reponse_json_success(data)


class RightExplainHandler(SevenBaseHandler):
    """
    @description: 右侧各种教程和说明导航
    """
    def get_async(self):
        """
        @description: 右侧各种教程和说明导航
        @param {*}
        @return dict
        @last_editors: HuangJingCan
        """
        base_info = BaseInfoModel().get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        data = []

        if base_info.course_strategy:
            data = ast.literal_eval(base_info.course_strategy)

        self.reponse_json_success(data)


class FriendLinkHandler(SevenBaseHandler):
    """
    @description: 获取友情链接
    """
    def get_async(self):
        """
        @description: 获取友情链接
        @param {*}
        @return list
        @last_editors: HuangJingCan
        """
        base_info = BaseInfoModel().get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        data = []

        if base_info.friend_link:
            data = ast.literal_eval(base_info.friend_link)

        self.reponse_json_success(data)


class UpdateInfoHandler(SevenBaseHandler):
    """
    @description: 获取更新信息
    """
    @filter_check_params("app_id")
    def get_async(self):
        """
        @description: 获取更新信息
        @param app_id：app_id
        @return dict
        @last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")

        base_info = BaseInfoModel().get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")
        app_info = AppInfoModel().get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("AppInfoError", "App信息出错")

        data = {}

        data["client_ver"] = base_info.client_ver
        data["server_ver"] = base_info.server_ver
        data["client_now_ver"] = app_info.template_ver
        data["update_function"] = []
        if base_info.update_function:
            data["update_function"] = ast.literal_eval(base_info.update_function)

        self.reponse_json_success(data)



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ThemeVerModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None):
        super(ThemeVerModel, self).__init__(ThemeVer, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class ThemeVer:

    def __init__(self):
        super(ThemeVer, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.out_id = ""  # 外部ID
        self.theme_id = 0  # 主题ID
        self.client_json = ""  # 客户端内容json
        self.ver_no = ""  # 客户端版本号
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'out_id', 'theme_id', 'client_json', 'ver_no', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "theme_ver_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-06-02 14:32:40
@LastEditTime: 2020-11-19 16:56:02
@LastEditors: HuangJingCan
@Description: 枚举类
"""

from enum import Enum, unique


class TagType(Enum):
    """
    @description: 标签类型
    """
    无 = 0
    限定 = 1
    稀有 = 2
    绝版 = 3
    隐藏 = 4


class SourceType(Enum):
    """
    @description: 用户次数配置来源类型
    """
    购买 = 1
    任务 = 2
    手动配置 = 3


class OperationType(Enum):
    """
    @description: 用户操作日志类型
    """
    add = 1
    update = 2
    delete = 3


class TaskType(Enum):
    """
    docstring：任务类型
    """
    # {"reward_value":0}
    掌柜有礼 = 1
    # {"reward_value":0}
    每日签到 = 2
    # {"reward_value":0,"user_limit":0}
    邀请新用户 = 3
    # {"reward_value":0}
    关注店铺 = 4
    # {"reward_value":0}
    加入店铺会员 = 5
    # {"reward_value":0,"num_limit":0,"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"goods_ids":"","goods_list":[]}
    下单购买指定商品 = 6
    # {"reward_value":0,"num_limit":0,"goods_ids":"","goods_list":[]}
    收藏商品 = 7
    # {"reward_value":0,"num_limit":0,"goods_ids":"","goods_list":[]}
    浏览商品 = 8
    # {"reward_value":0,"join_type":（1商家群链接2选择单群聊）,"join_url":"","chatting_id":"","chatting_name":""}
    加入群聊 = 9
    # {"reward_value":0,"chatting_id":"","chatting_name":""}
    分享群聊 = 10
    # 云应用未开放此功能
    直播 = 11
    # {"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0}
    每周签到 = 12
    # {"reward_value":0,"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00'}
    下单任意消费 = 13
    # {"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"reward_list":[{"key":"前端算唯一值","money":500,"reward_value":0}]}
    累计消费 = 14
    # {"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"reward_list":[{"key":"前端算唯一值","money":500,"reward_value":0}]}
    单笔订单消费 = 15
    # {"reward_value":0}
    新人有礼 = 16
    # 从活动奖品表配置
    店长好礼 = 17



# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-19 11:33:16
@LastEditTime: 2020-11-26 11:20:01
@LastEditors: HuangJingCan
@Description: 用户处理
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.behavior_model import *

from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.machine.machine_value_model import *

from seven_cloudapp.libs.customize.seven import *


class LoginHandler(SevenBaseHandler):
    """
    @description: 登录处理
    """
    @filter_check_params("act_id,open_id")
    def get_async(self):
        """
        @description: 登录日志入库
        @param owner_open_id：应用拥有者唯一标识
        @param act_id：活动id
        @return: dict
        @last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        user_nick = self.get_taobao_param().user_nick
        app_id = self.get_taobao_param().source_app_id
        owner_open_id = self.get_param("owner_open_id")
        act_id = int(self.get_param("act_id", 0))

        user_info_model = UserInfoModel()
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])

        act_info = ActInfoModel().get_entity("id=%s", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        if not user_info:
            user_info = UserInfo()
            user_info.open_id = open_id
            user_info.act_id = act_id
            user_info.app_id = app_id
            user_info.is_new = 1
            user_info.create_date = self.get_now_datetime()
            user_info.modify_date = self.get_now_datetime()
            user_info.login_token = SevenHelper.get_random(16, 1)
            user_info.id = user_info_model.add_entity(user_info)
        else:
            user_info.modify_date = self.get_now_datetime()
            user_info.login_token = SevenHelper.get_random(16, 1)
            user_info.is_new = 0
            user_info_model.update_entity(user_info, "modify_date,login_token,is_new")

        behavior_model = BehaviorModel()
        # 访问次数
        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitCountEveryDay', 1)
        # 访问人数
        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDay', 1)
        if user_info.is_new == 1:
            # 新增用户数
            behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDayIncrease', 1)

        self.reponse_json_success(user_info)


class LoginByMachineHandler(SevenBaseHandler):
    """
    @description: 登录处理（包含机台信息）
    """
    @filter_check_params("act_id,open_id")
    def get_async(self):
        """
        @description: 登录日志入库
        @param owner_open_id：应用拥有者唯一标识
        @param act_id：活动id
        @return: dict
        @last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        user_nick = self.get_taobao_param().user_nick
        app_id = self.get_taobao_param().source_app_id
        owner_open_id = self.get_param("owner_open_id")
        act_id = int(self.get_param("act_id", 0))

        user_info_model = UserInfoModel()
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])

        act_info = ActInfoModel().get_entity("id=%s", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        machine_info_model = MachineInfoModel()
        machine_info_list = machine_info_model.get_list("app_id=%s and act_id=%s", params=[app_id, act_id])
        if not machine_info_list:
            return self.reponse_json_error("NoMachine", "对不起，机台不存在")

        if not user_info:
            user_info = UserInfo()
            user_info.open_id = open_id
            user_info.act_id = act_id
            user_info.app_id = app_id
            user_info.is_new = 1
            user_info.create_date = self.get_now_datetime()
            user_info.modify_date = self.get_now_datetime()
            user_info.login_token = SevenHelper.get_random(16, 1)
            user_info.id = user_info_model.add_entity(user_info)
        else:
            user_info.modify_date = self.get_now_datetime()
            user_info.login_token = SevenHelper.get_random(16, 1)
            user_info.is_new = 0
            user_info_model.update_entity(user_info, "modify_date,login_token,is_new")

        machine_value_model = MachineValueModel()
        machine_value_list = machine_value_model.get_dict_list("open_id=%s", params=open_id)
        user_info_dict = user_info.__dict__
        user_info_dict["machine_value_list"] = machine_value_list

        behavior_model = BehaviorModel()
        # 访问次数
        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitCountEveryDay', 1)
        # 访问人数
        behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDay', 1)
        if user_info.is_new == 1:
            # 新增用户数
            behavior_model.report_behavior(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDayIncrease', 1)

        self.reponse_json_success(user_info_dict)


class UserHandler(SevenBaseHandler):
    """
    @description: 更新用户信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 更新用户信息
        @param avatar：头像
        @param act_id：活动id
        @return: 
        @last_editors: HuangJingCan
        """
        try:
            open_id = self.get_taobao_param().open_id
            user_nick = self.get_taobao_param().user_nick
            source_app_id = self.get_taobao_param().source_app_id
            avatar = self.get_param("avatar")
            act_id = int(self.get_param("act_id", 0))

            user_info_model = UserInfoModel()
            user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
            if not user_info:
                return self.reponse_json_error("NoUser", "对不起，用户不存在")

            user_info.user_nick = user_nick
            user_info.avatar = avatar
            user_info.is_auth = 1
            user_info.modify_date = self.get_now_datetime()
            user_info_model.update_entity(user_info)

            self.reponse_json_success("更新成功")
        except Exception as ex:
            self.reponse_json_error("Error", "更新失败")


# -*- coding: utf-8 -*-
"""
@Author: CaiYouBin
@Date: 2020-05-26 17:38:03
@LastEditTime: 2020-11-05 17:31:06
@LastEditors: HuangJingCan
@Description: 主题皮肤相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.theme.theme_info_model import *
from seven_cloudapp.models.db_models.theme.theme_ver_model import *
from seven_cloudapp.models.db_models.skin.skin_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *


class ThemeInfoHandler(SevenBaseHandler):
    """
    @description: 获取主题（皮肤）信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 获取主题（皮肤）信息
        @param act_id：活动id
        @param ver_no：客户端版本号
        @return 主题信息
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id"))
        ver_no = self.get_param("ver_no")
        act_info_model = ActInfoModel()
        theme_info_model = ThemeInfoModel()

        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if act_info:
            theme_info = theme_info_model.get_dict("id=%s", params=act_info.theme_id)
            if not theme_info:
                return self.reponse_json_error("NoTheme", "对不起，找不到该主题")
            out_id = theme_info["out_id"]
            if ver_no:
                theme_ver_model = ThemeVerModel()
                theme_ver = theme_ver_model.get_entity("out_id=%s and ver_no=%s", params=[out_id, ver_no])
                if theme_ver and theme_ver.client_json != "":
                    theme_info["client_json"] = theme_ver.client_json
            skin_info_model = SkinInfoModel()
            skin_info_list = skin_info_model.get_dict_list("theme_id=%s", params=act_info.theme_id)

            theme_info["skin_list"] = skin_info_list

            self.reponse_json_success(theme_info)
        else:
            self.reponse_json_error("NoAct", "对不起，找不到该活动")


class ThemeSaveHandler(SevenBaseHandler):
    """
    @description: 保存主题
    """
    @filter_check_params("out_id")
    def post_async(self):
        """
        @description: 保存主题
        @param app_id：app_id
        @param theme_name：主题名称
        @param client_json：客户端内容json
        @param server_json：服务端内容json
        @param out_id：外部id
        @param ver_no：客户端版本号
        @return: 
        @last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        # 1 新增  2修改
        theme_name = self.get_param("theme_name")
        client_json = self.get_param("client_json")
        server_json = self.get_param("server_json")
        out_id = self.get_param("out_id")
        ver_no = self.get_param("ver_no")
        theme_info_model = ThemeInfoModel()
        theme_ver_model = ThemeVerModel()
        theme_info = theme_info_model.get_entity("out_id=%s", params=out_id)
        if theme_info:
            if client_json:
                if ver_no:
                    theme_ver = theme_ver_model.get_entity('out_id=%s and ver_no=%s', params=[out_id, ver_no])
                    if theme_ver:
                        theme_ver_model.update_table('client_json=%s', 'out_id=%s and ver_no=%s', params=[client_json, out_id, ver_no])
                    else:
                        theme_ver = ThemeVer()
                        theme_ver.app_id = theme_info.app_id
                        theme_ver.out_id = out_id
                        theme_ver.theme_id = theme_info.id
                        theme_ver.client_json = client_json
                        theme_ver.ver_no = ver_no
                        theme_ver.create_date = theme_info.create_date
                        theme_ver_model.add_entity(theme_ver)
                else:
                    theme_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, out_id])
            if server_json:
                theme_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, out_id])
        else:
            theme_total = theme_info_model.get_total()
            if not theme_name:
                return self.reponse_json_error("NoThemeName", "对不起，请输入主题名称")
            theme_info = ThemeInfo()
            theme_info.theme_name = theme_name
            theme_info.client_json = client_json
            theme_info.server_json = server_json
            theme_info.out_id = out_id
            if app_id != "":
                theme_info.app_id = app_id
                theme_info.is_private = 1
            theme_info.sort_index = int(theme_total) + 1
            theme_info.is_release = 1
            theme_info.create_date = self.get_now_datetime()
            theme_id = theme_info_model.add_entity(theme_info)
            if ver_no:
                theme_ver = ThemeVer()
                theme_ver.app_id = theme_info.app_id
                theme_ver.out_id = out_id
                theme_ver.theme_id = theme_id
                theme_ver.client_json = client_json
                theme_ver.ver_no = ver_no
                theme_ver.create_date = theme_info.create_date
                theme_ver_model.add_entity(theme_ver)

        self.reponse_json_success()


class SkinSaveHandler(SevenBaseHandler):
    """
    @description: 保存皮肤
    """
    @filter_check_params("theme_out_id,skin_out_id")
    def post_async(self):
        """
        @description: 保存皮肤
        @param app_id：app_id
        @param skin_name：皮肤名称
        @param client_json：客户端内容json
        @param server_json：服务端内容json
        @param theme_out_id：样式外部id
        @param skin_out_id：皮肤外部id
        @return: 
        @last_editors: CaiYouBin
        """
        app_id = self.get_param("app_id")
        skin_name = self.get_param("skin_name")
        client_json = self.get_param("client_json")
        server_json = self.get_param("server_json")
        theme_out_id = self.get_param("theme_out_id")
        skin_out_id = self.get_param("skin_out_id")

        skin_info_model = SkinInfoModel()
        skin_info = skin_info_model.get_entity("out_id=%s", params=skin_out_id)
        if skin_info:
            if client_json:
                skin_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, skin_out_id])
            if server_json:
                skin_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, skin_out_id])
        else:
            skin_info_total = skin_info_model.get_total('theme_out_id=%s', params=theme_out_id)
            if not skin_name:
                return self.reponse_json_error("NoSkinName", "对不起，请输入皮肤名称")
            skin_info = SkinInfo()
            theme_info_model = ThemeInfoModel()
            theme_info = theme_info_model.get_entity("out_id=%s", params=theme_out_id)
            if not theme_info:
                return self.reponse_json_error("NoTheme", "没有找到对应主题")

            skin_info.skin_name = skin_name
            skin_info.client_json = client_json
            skin_info.server_json = server_json
            if app_id != "":
                skin_info.app_id = app_id
            skin_info.sort_index = skin_info_total + 1
            skin_info.theme_id = theme_info.id
            skin_info.create_date = self.get_now_datetime()
            skin_info.modify_date = self.get_now_datetime()
            skin_info.out_id = skin_out_id
            skin_info.theme_out_id = theme_out_id
            skin_id = skin_info_model.add_entity(skin_info)

        self.reponse_json_success()



# -*- coding: utf-8 -*-
"""
@Author: CaiYouBin
@Date: 2020-05-26 17:51:04
@LastEditTime: 2020-11-10 16:02:18
@LastEditors: HuangJingCan
@Description: 抽奖
"""
from seven_cloudapp.handlers.seven_base import *


class LotteryHandler(SevenBaseHandler):
    """
    @description: 抽奖逻辑实现（业务各自实现）
    """
    def get_async(self):
        """
        @description: 抽奖逻辑实现（业务各自实现）
        @param {*}
        @return {*}
        @last_editors: HuangJingCan
        """
        pass


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-11-05 10:03:55
@LastEditTime: 2020-11-24 17:25:11
@LastEditors: HuangJingCan
@Description: 机台相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo

from seven_cloudapp.models.db_models.machine.machine_info_model import *


class MachinieListHandler(SevenBaseHandler):
    """
    @description: 机台列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 获取机台列表
        @param act_id：活动id
        @param page_index：页索引
        @param page_size：页大小
        @return: 分页列表信息
        @last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        act_id = int(self.get_param("act_id", "0"))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))

        machine_info_model = MachineInfoModel()
        condition = "act_id=%s AND app_id=%s AND is_release=1"
        machine_info_page_list, total = machine_info_model.get_dict_page_list("*", page_index, page_size, condition, order_by="sort_index desc", params=[act_id, app_id])

        page_info = PageInfo(page_index, page_size, total, machine_info_page_list)

        self.reponse_json_success(page_info)


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-28 18:03:59
@LastEditTime: 2020-11-04 16:46:58
@LastEditors: HuangJingCan
@Description: 主题皮肤
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.theme.theme_info_model import *
from seven_cloudapp.models.db_models.skin.skin_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *


class ThemeListHandler(SevenBaseHandler):
    """
    @description: 主题列表
    """
    def get_async(self):
        """
        @description: 主题列表
        @param 
        @return: 列表
        @last_editors: HuangJingCan
        """
        theme_info_list = ThemeInfoModel().get_list("is_release=1")
        theme_list = []
        for info in theme_info_list:
            theme_info = {}
            theme_info["id"] = info.id
            theme_info["theme_name"] = info.theme_name
            theme_info["client_json"] = json.loads(info.client_json)
            theme_info["server_json"] = json.loads(info.server_json)
            theme_list.append(theme_info)

        self.reponse_json_success(theme_list)


class SkinListHandler(SevenBaseHandler):
    """
    @description: 皮肤列表
    """
    @filter_check_params("theme_id")
    def get_async(self):
        """
        @description: 皮肤列表
        @param theme_id：主题id
        @return: 列表
        @last_editors: HuangJingCan
        """
        theme_id = int(self.get_param("theme_id", 0))

        if theme_id <= 0:
            return self.reponse_json_error_params()

        skin_info_list = SkinInfoModel().get_list("theme_id=%s", params=theme_id)
        skin_list = []
        for info in skin_info_list:
            skin_info = {}
            skin_info["id"] = info.id
            skin_info["skin_name"] = info.skin_name
            skin_info["client_json"] = json.loads(info.client_json)
            skin_info["server_json"] = json.loads(info.server_json)
            skin_list.append(skin_info)

        self.reponse_json_success(skin_list)


class ThemeUpdate(SevenBaseHandler):
    """
    @description: 小程序主题更新
    """
    @filter_check_params("act_id,theme_id")
    def get_async(self):
        """
        @description: 小程序主题更新
        @param act_id：活动id
        @param theme_id：主题id
        @return: 
        @last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        act_id = self.get_param("act_id")
        theme_id = int(self.get_param("theme_id"))

        act_info_model = ActInfoModel()
        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")
        if act_info.theme_id == theme_id:
            return self.reponse_json_error("NoAct", "对不起，主题未改变")

        skin_info = SkinInfoModel().get_entity("theme_id=%s", params=theme_id)
        if not skin_info:
            return self.reponse_json_error("NoAct", "对不起，主题没有皮肤")

        act_info_model.update_table("theme_id=%s", "id=%s", [theme_id, act_id])

        MachineInfoModel().update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])

        self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
@Author: CaiYouBin
@Date: 2020-05-26 15:26:32
@LastEditTime: 2020-11-24 17:25:31
@LastEditors: HuangJingCan
@Description: 客户端活动处理
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo

from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *


class ActInfoHandler(SevenBaseHandler):
    """
    @description: 获取活动信息
    """
    def get_async(self):
        """
        @description: 获取活动信息
        @param act_id：活动id
        @return: 字典
        @last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))

        app_id = self.get_taobao_param().source_app_id

        app_info_model = AppInfoModel()
        app_info = app_info_model.get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，找不到该小程序")

        act_info_model = ActInfoModel()
        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")

        act_info.store_id = app_info.store_id
        act_info.store_name = app_info.store_name

        self.reponse_json_success(act_info)


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-29 09:40:42
@LastEditTime: 2020-11-24 17:23:48
@LastEditors: HuangJingCan
@Description: 机台（盒子）
"""
import decimal
import copy
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import *
from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.throw_model import *

from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.machine.machine_value_model import *
from seven_cloudapp.models.db_models.machine.machine_value_log_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
from seven_cloudapp.models.db_models.behavior.behavior_report_model import *
from seven_cloudapp.models.db_models.coin.coin_order_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *


class MachineHandler(SevenBaseHandler):
    """
    @description: 保存机台（业务各自实现）
    """
    @filter_check_params("act_id,machine_name")
    def post_async(self):
        """
        @description: 保存机台（业务各自实现）
        @param act_id：活动id
        @param machine_name：机台名称
        @return: 
        @last_editors: HuangJingCan
        """
        pass


class MachineListHandler(SevenBaseHandler):
    """
    @description: 获取机台列表（业务各自实现）
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 获取机台列表（业务各自实现）
        @param act_id：活动id
        @param page_index：页索引
        @param page_size：页大小
        @return: 列表
        @last_editors: HuangJingCan
        """
        pass


class MachineDelHandler(SevenBaseHandler):
    """
    @description: 删除机台
    """
    @filter_check_params("machine_id")
    def get_async(self):
        """
        @description: 删除机台
        @param machine_id：机台id
        @return: 
        @last_editors: HuangJingCan
        """
        machine_id = int(self.get_param("machine_id", "0"))

        if machine_id <= 0:
            return self.reponse_json_error_params()

        machine = MachineInfoModel().get_dict('id=%s', params=machine_id)

        ActPrizeModel().del_entity("machine_id=%s", machine_id)

        MachineInfoModel().del_entity("id=%s", machine_id)

        MachineValueModel().del_entity("machine_id=%s", machine_id)

        BehaviorOrmModel().del_entity("key_name='openUserCount_" + str(machine_id) + "' or key_name='openCount_" + str(machine_id) + "'")

        ThrowModel().throw_goods_update(machine.act_id, machine.goods_id, self.get_now_datetime())

        self.create_operation_log(OperationType.delete.value, "machine_info_tb", "MachineHandler", None, machine_id)

        self.reponse_json_success()


class MachineReleaseHandler(SevenBaseHandler):
    """
    @description: 机台上下架
    """
    @filter_check_params("machine_id,is_release")
    def get_async(self):
        """
        @description: 机台上下架
        @param machine_id：机台id
        @param is_release：是否发布（0下架1上架）
        @return: 
        @last_editors: HuangJingCan
        """
        machine_id = int(self.get_param("machine_id", "0"))
        is_release = int(self.get_param("is_release", "0"))

        if machine_id <= 0:
            return self.reponse_json_error_params()

        MachineInfoModel().update_table("is_release=%s", "id=%s", [is_release, machine_id])

        self.reponse_json_success()


class MachineValueLogHandler(SevenBaseHandler):
    """
    @description: 用户机台配置记录
    """
    @filter_check_params("act_id,user_open_id")
    def get_async(self):
        """
        @description: 用户机台配置记录
        @param act_id：活动id
        @param user_open_id：用户唯一标识
        @return 列表
        @last_editors: HuangJingCan
        """
        act_id = self.get_param("act_id")
        user_open_id = self.get_param("user_open_id")

        machine_info_model = MachineInfoModel()
        machine_value_model = MachineValueModel()
        machine_value_log_model = MachineValueLogModel()

        machine_info_list = machine_info_model.get_list("act_id=%s", params=act_id)
        machine_value_log_list_dict = machine_value_log_model.get_dict_list("act_id=%s and open_id=%s", order_by='create_date desc', params=[act_id, user_open_id])
        machine_value_list = machine_value_model.get_list("act_id=%s and open_id=%s", params=[act_id, user_open_id])

        machine_value_log_groups = []
        for machine_info in machine_info_list:
            machine_value_log_group = {}
            machine_value_log_group["machine_id"] = machine_info.id
            machine_value_log_group["machine_name"] = machine_info.machine_name
            for machine_value in machine_value_list:
                if machine_value.machine_id == machine_info.id:
                    machine_value_log_group["surplus_value"] = machine_value.surplus_value
                    machine_value_log_group["open_value"] = machine_value.open_value
                    continue
            if "surplus_value" not in machine_value_log_group.keys():
                machine_value_log_group["surplus_value"] = 0
            if "open_value" not in machine_value_log_group.keys():
                machine_value_log_group["open_value"] = 0
            machine_value_log_group["machine_value_log_list"] = [i for i in machine_value_log_list_dict if i["machine_id"] == machine_info.id]
            machine_value_log_groups.append(machine_value_log_group)

        self.reponse_json_success(machine_value_log_groups)


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-05-26 14:45:44
@LastEditTime: 2020-11-04 17:26:35
@LastEditors: HuangJingCan
@Description: 通用Handler
"""
from seven_cloudapp.handlers.seven_base import *


class IndexHandler(SevenBaseHandler):
    """
    @description: 默认页
    """
    def get_async(self):
        """
        @description: 默认页
        @param 
        @return 字符串
        @last_editors: HuangJingCan
        """
        self.write(config.get_value("project_name") + "_api")


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-06-05 17:10:27
@LastEditTime: 2020-11-24 09:58:49
@LastEditors: HuangJingCan
@Description: 统计相关
"""
import decimal

from seven_cloudapp.libs.customize.seven import *

from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
from seven_cloudapp.models.db_models.behavior.behavior_report_model import *


class BehaviorModel():
    """
    @description: 统计相关
    """
    def report_behavior(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        @description: 上报行为记录
        @param app_id：app_id
        @param act_id：活动id
        @param open_id：open_id
        @param owner_open_id：owner_open_id
        @param behavior_key：统计key
        @param behavior_value：统计值
        @return: 
        @last_editors: CaiYouBin
        """
        behavior_orm_model = BehaviorOrmModel()
        behavior_log_model = BehaviorLogModel()
        behavior_report_model = BehaviorReportModel()
        orm = None
        behavior_log = None
        if act_type > 0:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s and act_type=%s", params=[act_id, behavior_key, act_type])
        else:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s", params=[act_id, behavior_key])
        if not orm:
            return "NotOrm"
        if orm.is_repeat == 1:
            if orm.repeat_type == 2:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s", params=[orm.id, act_id, open_id])
            else:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s and to_days(create_date)=to_days(now())", params=[orm.id, act_id, open_id])
            if not behavior_log:
                behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and to_days(create_date) = to_days(now())", params=[act_id, app_id, behavior_key])
                if not behavior_report:
                    behavior_report = BehaviorReport()
                    behavior_report.app_id = app_id
                    behavior_report.act_id = act_id
                    # behavior_report.owner_open_id
                    behavior_report.key_name = behavior_key
                    behavior_report.key_value = behavior_value
                    behavior_report.create_year = (datetime.datetime.now() + datetime.timedelta(hours=8)).year
                    behavior_report.create_month = (datetime.datetime.now() + datetime.timedelta(hours=8)).month
                    behavior_report.create_day = (datetime.datetime.now() + datetime.timedelta(hours=8)).day
                    behavior_report.create_date = TimeHelper.add_hours_by_format_time(hour=8)
                    behavior_report_model.add_entity(behavior_report)
                else:
                    behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                    behavior_report_model.update_entity(behavior_report)
        else:
            behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and to_days(create_date) = to_days(now())", params=[act_id, app_id, behavior_key])
            if not behavior_report:
                behavior_report = BehaviorReport()
                behavior_report.app_id = app_id
                behavior_report.act_id = act_id
                # behavior_report.owner_open_id
                behavior_report.key_name = behavior_key
                behavior_report.key_value = behavior_value
                behavior_report.create_year = (datetime.datetime.now() + datetime.timedelta(hours=8)).year
                behavior_report.create_month = (datetime.datetime.now() + datetime.timedelta(hours=8)).month
                behavior_report.create_day = (datetime.datetime.now() + datetime.timedelta(hours=8)).day
                behavior_report.create_date = TimeHelper.add_hours_by_format_time(hour=8)
                behavior_report_model.add_entity(behavior_report)
            else:
                behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                behavior_report_model.update_entity(behavior_report)

        new_behavior_log = BehaviorLog()
        new_behavior_log.app_id = app_id
        new_behavior_log.act_id = act_id
        new_behavior_log.open_id = open_id
        new_behavior_log.orm_id = orm.id
        new_behavior_log.inc_value = behavior_value
        new_behavior_log.create_date = TimeHelper.add_hours_by_format_time(hour=8)

        behavior_log_model.add_entity(new_behavior_log)

    def report_behavior_log(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        @description: 新统计上报,数据库表(behavior_report_tb)加唯一索引（app_id,act_id,key_name,create_day)）,避免重复数据
        @param app_id：app_id
        @param act_id：活动id
        @param open_id：open_id
        @param owner_open_id：owner_open_id
        @param behavior_key：统计key
        @param behavior_value：统计值
        @return: 
        @last_editors: CaiYouBin
        """
        try:
            self.process_behavior(app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type)
        except Exception as ex:
            if str(ex).__contains__("Duplicate entry"):
                self.process_behavior(app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type)

    def process_behavior(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        @description: 上报行为记录
        @param app_id：app_id
        @param act_id：活动id
        @param open_id：open_id
        @param owner_open_id：owner_open_id
        @param behavior_key：统计key
        @param behavior_value：统计值
        @return: 
        @last_editors: HuangJianYi
        """
        behavior_orm_model = BehaviorOrmModel()
        behavior_log_model = BehaviorLogModel()
        behavior_report_model = BehaviorReportModel()
        orm = None
        behavior_log = None
        if act_type > 0:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s and act_type=%s", params=[act_id, behavior_key, act_type])
        else:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s", params=[act_id, behavior_key])
        if not orm:
            return "NotOrm"
        if orm.is_repeat == 1:
            if orm.repeat_type == 2:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s", params=[orm.id, act_id, open_id])
            else:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s and to_days(create_date)=to_days(now())", params=[orm.id, act_id, open_id])
            if not behavior_log:
                behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and create_day=%s", params=[act_id, app_id, behavior_key, SevenHelper.get_now_day_int(8)])
                if not behavior_report:
                    behavior_report = BehaviorReport()
                    behavior_report.app_id = app_id
                    behavior_report.act_id = act_id
                    # behavior_report.owner_open_id
                    behavior_report.key_name = behavior_key
                    behavior_report.key_value = behavior_value
                    behavior_report.create_year = (datetime.datetime.now() + datetime.timedelta(hours=8)).year
                    behavior_report.create_month = SevenHelper.get_now_month_int(8)
                    behavior_report.create_day = SevenHelper.get_now_day_int(8)
                    behavior_report.create_date = TimeHelper.add_hours_by_format_time(hour=8)
                    behavior_report_model.add_entity(behavior_report)

                else:
                    behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                    behavior_report_model.update_entity(behavior_report)
        else:
            behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and  create_day=%s", params=[act_id, app_id, behavior_key, SevenHelper.get_now_day_int(8)])
            if not behavior_report:
                behavior_report = BehaviorReport()
                behavior_report.app_id = app_id
                behavior_report.act_id = act_id
                # behavior_report.owner_open_id
                behavior_report.key_name = behavior_key
                behavior_report.key_value = behavior_value
                behavior_report.create_year = (datetime.datetime.now() + datetime.timedelta(hours=8)).year
                behavior_report.create_month = SevenHelper.get_now_month_int(8)
                behavior_report.create_day = SevenHelper.get_now_day_int(8)
                behavior_report.create_date = TimeHelper.add_hours_by_format_time(hour=8)
                behavior_report_model.add_entity(behavior_report)
            else:
                behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                behavior_report_model.update_entity(behavior_report)

        new_behavior_log = BehaviorLog()
        new_behavior_log.app_id = app_id
        new_behavior_log.act_id = act_id
        new_behavior_log.open_id = open_id
        new_behavior_log.orm_id = orm.id
        new_behavior_log.inc_value = behavior_value
        new_behavior_log.create_date = TimeHelper.add_hours_by_format_time(hour=8)

        behavior_log_model.add_entity(new_behavior_log)

    def save_orm(self, orm_infos, act_id):
        """
        @description: 保存Orm
        @param orm_infos：orm_infos
        @param act_id：活动id
        @return: 
        @last_editors: CaiYouBin
        """
        delete_orm_ids = []
        behavior_orm_model = BehaviorOrmModel()
        behavior_orm_list = behavior_orm_model.get_list('act_id=%s', params=act_id)
        for behavior_orm_item in behavior_orm_list:
            if behavior_orm_item.key_name.find(orm_infos[0].key_name) != -1:
                delete_orm_ids.append(str(behavior_orm_item.id))
            if behavior_orm_item.key_name.find(orm_infos[1].key_name) != -1:
                delete_orm_ids.append(str(behavior_orm_item.id))
        if len(delete_orm_ids) > 0:
            behavior_orm_model.del_entity('id in (' + ','.join(delete_orm_ids) + ')')

        behavior_orm_model.add_list(orm_infos)


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-06-02 13:44:17
@LastEditTime: 2020-11-25 15:02:57
@LastEditors: HuangJingCan
@Description: 奖品相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.enum import *
from seven_cloudapp.models.seven_model import *
from seven_cloudapp.models.throw_model import *

from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *


class PrizeListHandler(SevenBaseHandler):
    """
    @description: 奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 奖品列表
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param ascription_type：奖品归属（0-活动奖品1-任务奖品）
        @return: PageInfo
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        ascription_type = int(self.get_param("ascription_type", 0))

        condition = "act_id=%s"
        order_by = "sort_index desc"
        params = [act_id]

        if act_id <= 0:
            return self.reponse_json_error_params()

        if ascription_type == 1:
            condition += " AND ascription_type=1"

        act_prize_model = ActPrizeModel()

        prize_all_count = 0
        prize_surplus_count = 0
        prize_lottery_count = 0
        sum_probability = {'probability': 0}

        if ascription_type == 0:
            # 奖品总件数
            prize_all_count = act_prize_model.get_total("act_id=%s", params=act_id)
            # 库存不足奖品件数
            prize_surplus_count = act_prize_model.get_total("act_id=%s AND surplus=0", params=act_id)
            # 可被抽中奖品件数
            prize_lottery_count = act_prize_model.get_total("act_id=%s AND probability>0 AND surplus>0 AND is_release=1", params=act_id)
            #奖品总权重
            sum_probability = act_prize_model.get_dict("act_id=%s and is_release=1", field="sum(probability) as probability", params=act_id)

        page_list, total = act_prize_model.get_dict_page_list("*", page_index, page_size, condition, "", order_by, act_id)

        for page in page_list:
            page["prize_detail"] = json.loads(page["prize_detail"]) if page["prize_detail"] else []
            page["goods_code_list"] = json.loads(page["goods_code_list"]) if page["goods_code_list"] else []
            page["sku_detail"] = json.loads(page["sku_detail"]) if page["sku_detail"] else []

        page_info = PageInfo(page_index, page_size, total, page_list)

        page_info.prize_all_count = prize_all_count
        page_info.prize_surplus_count = prize_surplus_count
        page_info.prize_lottery_count = prize_lottery_count
        page_info.prize_sum_probability = int(sum_probability["probability"]) if sum_probability["probability"] else 0

        self.reponse_json_success(page_info)


class PrizeHandler(SevenBaseHandler):
    """
    @description: 奖品保存（业务各自实现）
    """
    @filter_check_params("machine_id,prize_name")
    def post_async(self):
        """
        @description: 奖品保存（业务各自实现）
        @param prize_id：奖品id
        @return: 
        @last_editors: HuangJingCan
        """
        pass


class PrizeDelHandler(SevenBaseHandler):
    """
    @description: 删除奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        @description: 删除奖品
        @param prize_id：奖品id
        @return: reponse_json_success
        @last_editors: HuangJingCan
        """
        prize_id = int(self.get_param("prize_id", 0))

        if prize_id <= 0:
            return self.reponse_json_error_params()

        ActPrizeModel().del_entity("id=%s", prize_id)

        self.create_operation_log(OperationType.delete.value, "act_prize_tb", "PrizeDelHandler", None, prize_id)

        self.reponse_json_success()


class PrizeDelByThrowHandler(SevenBaseHandler):
    """
    @description: 删除奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        @description: 删除奖品
        @param prize_id：奖品id
        @return: reponse_json_success
        @last_editors: HuangJingCan
        """
        prize_id = int(self.get_param("prize_id", 0))

        if prize_id <= 0:
            return self.reponse_json_error_params()

        act_prize_model = ActPrizeModel()
        act_prize = act_prize_model.get_entity("id=%s", params=prize_id)

        if not act_prize:
            return self.reponse_json_success()

        act_prize_model.del_entity("id=%s", prize_id)

        #投放商品处理
        ThrowModel().throw_goods_update(act_prize.act_id, act_prize.goods_id, self.get_now_datetime())

        self.create_operation_log(OperationType.delete.value, "act_prize_tb", "PrizeDelByThrowHandler", None, prize_id)

        self.reponse_json_success()


class PrizeReleaseHandler(SevenBaseHandler):
    """
    @description: 上下架奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        @description: 上下架奖品
        @param prize_id：奖品id
        @param is_release：0-下架，1-上架
        @return: 
        @last_editors: HuangJingCan
        """
        prize_id = int(self.get_param("prize_id", 0))
        is_release = int(self.get_param("is_release", 0))
        modify_date = self.get_now_datetime()

        if prize_id <= 0:
            return self.reponse_json_error_params()

        ActPrizeModel().update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, prize_id])

        self.reponse_json_success()


class CheckRightEnameHandler(SevenBaseHandler):
    """
    @description: 判断奖品里面有没有添加这张优惠券
    """
    @filter_check_params("right_ename")
    def get_async(self):
        """
        @description: 判断奖品里面有没有添加这张优惠券
        @param right_ename：优惠券标识
        @return reponse_json_success
        @last_editors: HuangJingCan
        """
        right_ename = self.get_param("right_ename")

        count = ActPrizeModel().get_total("right_ename=%s", params=right_ename)
        if count > 0:
            return self.reponse_json_error()

        self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-06-02 11:08:39
@LastEditTime: 2020-11-26 16:05:19
@LastEditors: HuangJingCan
@Description: 订单相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.pay.pay_order_model import *
from seven_cloudapp.models.db_models.prize.prize_order_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.seven_model import *

from seven_cloudapp.libs.customize.seven import *


class PayOrderListHandler(SevenBaseHandler):
    """
    @description: 用户购买订单
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 用户购买订单
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param user_open_id：用户唯一标识
        @param pay_date_start：订单支付时间开始
        @param pay_date_end：订单支付时间结束
        @param nick_name：用户昵称
        @return: 列表
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        user_open_id = self.get_param("user_open_id")
        pay_date_start = self.get_param("pay_date_start")
        pay_date_end = self.get_param("pay_date_end")
        user_nick = self.get_param("nick_name")

        condition = "act_id=%s"
        params = [act_id]

        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)
        if pay_date_start:
            condition += " AND pay_date>=%s"
            params.append(pay_date_start)
        if pay_date_end:
            condition += " AND pay_date<=%s"
            params.append(pay_date_end)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)

        page_list, total = PayOrderModel().get_dict_page_list("*", page_index, page_size, condition, "", "pay_date desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)


class PrizeOrderListHandler(SevenBaseHandler):
    """
    @description: 用户奖品订单
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 用户奖品订单
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param order_no：订单号
        @param nick_name：用户昵称
        @param real_name：用户名字
        @param telephone：联系电话
        @param adress：收货地址
        @param order_status：订单状态
        @param create_date_start：订单创建时间开始
        @param create_date_end：订单创建时间结束
        @return: 列表
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        user_nick = self.get_param("nick_name")
        real_name = self.get_param("real_name")
        telephone = self.get_param("telephone")
        adress = self.get_param("adress")
        order_status = self.get_param("order_status")
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")

        condition = "act_id=%s"
        params = [act_id]

        if order_no:
            condition += " AND order_no=%s"
            params.append(order_no)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if real_name:
            condition += " AND real_name=%s"
            params.append(user_nick)
        if telephone:
            condition += " AND telephone=%s"
            params.append(telephone)
        if adress:
            adress = f"%{adress}%"
            condition += " AND adress LIKE %s"
            params.append(adress)
        if order_status or order_status == "-1":
            condition += " AND order_status=%s"
            params.append(order_status)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)

        page_list, total = PrizeOrderModel().get_dict_page_list("*", page_index, page_size, condition, "", "id desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)


class PrizeRosterListHandler(SevenBaseHandler):
    """
    @description: 用户奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        @description: 用户奖品列表
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param prize_order_id：奖品订单id
        @param prize_type：奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
        @param nick_name：用户昵称
        @param is_submit：是否提交
        @param order_status：订单状态
        @param create_date_start：订单创建时间开始
        @param create_date_end：订单创建时间结束
        @param user_open_id：用户唯一标识
        @return: list
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        prize_order_id = int(self.get_param("prize_order_id", 0))
        user_nick = self.get_param("nick_name")
        is_submit = self.get_param("is_submit")
        prize_type = int(self.get_param("prize_type", 0))
        order_status = int(self.get_param("order_status", 0))
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")
        user_open_id = self.get_param("user_open_id")

        condition = "act_id=%s"
        params = [act_id]

        if prize_order_id > 0:
            condition += " AND prize_order_id=%s"
            params.append(prize_order_id)
        if prize_type > 0:
            condition += " AND prize_type=%s"
            params.append(prize_type)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if is_submit and is_submit != "-1":
            if is_submit == "0":
                condition += " AND prize_order_id=0"
            else:
                condition += " AND prize_order_id>0"
        if order_status:
            condition += " AND order_status=%s"
            params.append(order_status)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)
        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)

        page_list, total = PrizeRosterModel().get_dict_page_list("*", page_index, page_size, condition, "", "id desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)


class PrizeOrderStatusHandler(SevenBaseHandler):
    """
    @description: 更新用户奖品订单状态
    """
    @filter_check_params("prize_order_id,order_status")
    def post_async(self):
        """
        @description: 更新用户奖品订单状态
        @param prize_order_id：奖品订单id
        @param order_status：订单状态
        @param express_company：快递公司
        @param express_no：快递单号
        @return: 
        @last_editors: HuangJingCan
        """
        prize_order_id = int(self.get_param("prize_order_id", 0))
        order_status = int(self.get_param("order_status", 0))
        express_company = self.get_param("express_company")
        express_no = self.get_param("express_no")

        prize_order_model = PrizeOrderModel()

        if order_status == 1:
            update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
            params = [express_company, express_no, self.get_now_datetime(), prize_order_id]
            prize_order_model.update_table(update_sql, "id=%s", params)

            self.reponse_json_success({"express_company": express_company, "express_no": express_no, "deliver_date": self.get_now_datetime()})
        else:
            prize_order_model.update_table("order_status=%s", "id=%s", [order_status, prize_order_id])

            self.reponse_json_success()


class PrizeOrderRemarksHandler(SevenBaseHandler):
    """
    @description: 更新用户奖品订单备注
    """
    @filter_check_params("prize_order_id,remarks")
    def post_async(self):
        """
        @description: 更新用户奖品订单备注
        @param prize_order_id：奖品订单id
        @param remarks：备注
        @return: 
        @last_editors: HuangJingCan
        """
        prize_order_id = int(self.get_param("prize_order_id", 0))
        remarks = self.get_param("remarks")

        PrizeOrderModel().update_table("remarks=%s", "id=%s", [remarks, prize_order_id])

        self.reponse_json_success()


class PrizeOrderExportHandler(SevenBaseHandler):
    """
    @description: 批量导出
    """
    def get_async(self):
        """
        @description: 批量导出
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param order_no：订单号
        @param order_status：订单状态
        @param nick_name：用户昵称
        @return 字符串
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 500))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        order_status = self.get_param("order_status")
        user_nick = self.get_param("nick_name")

        condition = "act_id=%s"
        params = [act_id]
        
        if order_no != "":
            condition = "order_no=%s"
            params.append(order_no)
        if user_nick != "":
            params.append(user_nick)
            if condition == "":
                condition = "user_nick=%s"
            else:
                condition += " AND user_nick=%s"
        if order_status != "":
            params.append(int(order_status))
            if condition == "":
                condition = "order_status=%s"
            else:
                condition += " AND order_status=%s"

        prize_order_model = PrizeOrderModel()
        prize_roster_model = PrizeRosterModel()

        #奖品订单
        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, "", "create_date desc", params)

        data_columns = ["小程序订单号", "淘宝子订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "商家编码", "姓名", "手机号", "省份", "城市", "区县", "街道", "收货地址", "物流单号", "物流公司", "发货时间", "订单状态", "奖品价值", "奖品规格", "备注"]

        data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"

        result_data = []
        if len(prize_order_list_dict) > 0:
            prize_order_id_list = [prize_order["id"] for prize_order in prize_order_list_dict]
            prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
            #订单奖品
            prize_roster_list = prize_roster_model.get_dict_list("prize_order_id in (" + prize_order_ids + ")", order_by="id desc")

            for prize_order in prize_order_list_dict:
                prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
                for prize_roster in prize_roster_list_filter:

                    data_row = []
                    data_row.append("\'" + prize_order["order_no"])
                    data_row.append("\'" + prize_roster["order_no"])
                    data_row.append(prize_order["user_nick"])
                    data_row.append(prize_roster["machine_name"])
                    data_row.append(str(prize_roster["machine_price"]))
                    data_row.append(prize_roster["prize_name"])
                    data_row.append(prize_roster["goods_code"])
                    data_row.append(prize_order["real_name"])
                    data_row.append(prize_order["telephone"])
                    data_row.append(prize_order["province"])
                    data_row.append(prize_order["city"])
                    data_row.append(prize_order["county"])
                    data_row.append(prize_order["street"])
                    data_row.append(prize_order["adress"])
                    data_row.append(prize_order["express_no"])
                    data_row.append(prize_order["express_company"])
                    if str(prize_order["deliver_date"]) == "1900-01-01 00:00:00":
                        data_row.append("")
                    else:
                        data_row.append(str(prize_order["deliver_date"]))
                    data_row.append(self.get_status_name(prize_order["order_status"]))
                    data_row.append(str(prize_roster["prize_price"]))
                    data_row.append(prize_roster["properties_name"])
                    data_row.append(prize_order["remarks"])

                    data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"

        self.reponse_json_success(data_text)


class PrizeOrderImportHandler(SevenBaseHandler):
    """
    @description: 批量导入(批量发货)
    """
    @filter_check_params("content")
    def post_async(self):
        """
        @description: 批量导入(批量发货)
        @param content：内容
        @param act_id：活动id
        @return 
        @last_editors: HuangJingCan
        """
        content = self.get_param("content")
        act_id = int(self.get_param("act_id", 0))
        content_json = json.loads(content)

        prize_order_model = PrizeOrderModel()

        order_no_index = -1
        express_no_index = -1
        express_company_index = -1
        title_arr = content_json[0].replace("\'", "").split(",")
        if len(title_arr) == 0:
            return self.reponse_json_error("NoTitle", "对不起,未找到字段名称")

        title_arr_index = 0
        for title in title_arr:
            title = title.replace("\"", "").replace("\'", "")

            if "小程序订单号" == title:
                order_no_index = title_arr_index
            if "物流公司" == title:
                express_company_index = title_arr_index
            if "物流单号" == title:
                express_no_index = title_arr_index
            title_arr_index += 1

        if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
            return self.reponse_json_error("NoTitle", "对不起,缺少必要字段，无法导入订单")

        for i in range(1, len(content_json)):
            fields = content_json[i].replace("\'", "").split(",")
            if len(fields) == 0:
                continue

            #去掉多余的单（双）引号
            order_no = fields[order_no_index].replace("\"", "").replace("\'", "")
            express_no = fields[express_no_index].replace("\"", "").replace("\'", "")
            express_company = fields[express_company_index].replace("\"", "").replace("\'", "")

            if order_no and express_no and express_company:
                update_sql = "express_no=%s, express_company=%s, order_status=1, deliver_date=%s"
                params = [express_no, express_company, self.get_now_datetime(), order_no, act_id]
                prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s ", params=params)

        self.reponse_json_success()


class PrizeRosterListExportHandler(SevenBaseHandler):
    """
    @description: 批量奖品列表导出
    """
    def get_async(self):
        """
        @description: 批量奖品列表导出
        @param page_index：页索引
        @param page_size：页大小
        @param act_id：活动id
        @param order_no：订单号
        @param order_status：订单状态
        @param nick_name：用户昵称
        @return 字符串
        @last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 500))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        order_status = self.get_param("order_status")
        user_nick = self.get_param("nick_name")

        condition = "act_id=%s"
        params = [act_id]
        
        if order_no != "":
            condition = "order_no=%s"
            params.append(order_no)
        if user_nick != "":
            params.append(user_nick)
            if condition == "":
                condition = "user_nick=%s"
            else:
                condition += " AND user_nick=%s"
        if order_status != "":
            params.append(int(order_status))
            if condition == "":
                condition = "order_status=%s"
            else:
                condition += " AND order_status=%s"

        prize_order_model = PrizeOrderModel()
        prize_roster_model = PrizeRosterModel()

        #奖品订单
        prize_roster_list, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        data_columns = ["行为编号", "淘宝子订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "奖品价值", "SKU", "获得时间", "状态"]

        data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"

        result_data = []
        if len(prize_roster_list) > 0:
            #订单奖品
            for prize_roster in prize_roster_list:
                data_row = []
                data_row.append(str(prize_roster["id"]))
                if prize_roster["order_no"] == "":
                    data_row.append(prize_roster["order_no"])
                else:
                    data_row.append("\'" + prize_roster["order_no"])
                data_row.append(prize_roster["user_nick"])
                data_row.append(prize_roster["machine_name"])
                data_row.append(str(prize_roster["machine_price"]))
                data_row.append(prize_roster["prize_name"])
                data_row.append(str(prize_roster["prize_price"]))
                data_row.append(prize_roster["properties_name"])
                data_row.append(TimeHelper.datetime_to_format_time(prize_roster["create_date"]))
                if prize_roster["prize_order_id"] == 0:
                    data_row.append("未下单")
                else:
                    data_row.append("已下单")
                data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"

        self.reponse_json_success(data_text)


# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-11-03 16:25:11
@LastEditTime: 2020-11-10 16:02:54
@LastEditors: HuangJingCan
@Description: 
"""

from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *


class ThrowModel():
    """
    @description: 投放相关
    """
    def throw_goods_add(self, object_id, app_id, act_id, goods_id, old_act_id, old_goods_id, now_datetime):
        """
        @description: 投放商品处理
        @param object_id：对象id（机台id或者奖品id）
        @param app_id：app_id
        @param act_id：活动id
        @param goods_id：投放id
        @param old_act_id：旧活动id
        @param old_goods_id：旧投放id
        @param now_datetime：当前时间
        @return
        @last_editors: HuangJingCan
        """
        act_prize_model = ActPrizeModel()
        act_info_model = ActInfoModel()
        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if act_info.is_throw == 1:
            throw_goods_model = ThrowGoodsModel()
            if object_id > 0:
                # 商品ID与之前不同的话，改变原该投放商品的状态，并添加新商品ID
                if goods_id != old_goods_id:
                    machine_info_model = MachineInfoModel()
                    prize_throw_goods_exist = act_prize_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, old_goods_id])
                    machine_throw_goods_exist = machine_info_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, old_goods_id])
                    if not prize_throw_goods_exist and not machine_throw_goods_exist:
                        throw_goods_model.update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[now_datetime, old_act_id, old_goods_id])

                    throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
                    if not throw_goods:
                        throw_goods = ThrowGoods()
                        throw_goods.app_id = app_id
                        throw_goods.act_id = act_id
                        throw_goods.goods_id = goods_id
                        throw_goods.is_throw = 0
                        throw_goods.is_sync = 0
                        throw_goods_model.add_entity(throw_goods)
            else:
                throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
                if not throw_goods:
                    throw_goods = ThrowGoods()
                    throw_goods.app_id = app_id
                    throw_goods.act_id = act_id
                    throw_goods.goods_id = goods_id
                    throw_goods.is_throw = 0
                    throw_goods.is_sync = 0
                    throw_goods_model.add_entity(throw_goods)

    def throw_goods_update(self, act_id, goods_id, now_datetime):
        """
        @description: 投放商品处理
        @param act_id：活动id
        @param goods_id：投放id
        @param now_datetime：当前时间
        @return
        @last_editors: HuangJingCan
        """
        act_prize_model = ActPrizeModel()
        act_info_model = ActInfoModel()
        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if act_info.is_throw == 1:
            throw_goods_model = ThrowGoodsModel()
            machine_info_model = MachineInfoModel()
            prize_throw_goods_exist = act_prize_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
            machine_throw_goods_exist = machine_info_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
            if not prize_throw_goods_exist and not machine_throw_goods_exist:
                throw_goods_model.update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[now_datetime, act_id, goods_id])



# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-04-16 14:38:22
@LastEditTime: 2020-08-12 14:44:37
@LastEditors: HuangJingCan
@Description: 
"""
__all__ = ["base_s", "app_s", "user_s", "act_s", "theme_s", "machine_s", "goods_s", "order_s", "prize_s", "report_s", "sms_s", "price_s", "throw_s"]